@@ -84,12 +84,12 @@ class SourceDevice:
                     continue
                 if trigger == 1 and 'ip address ' in line:
                     net_info = line.strip().split(' ')
-                    self.ip = ({'ip': net_info[2]})
-                    self.netmask = ({'netmask': net_info[3]})
+                    self.ip = net_info[2]
+                    self.netmask = net_info[3]
                     trigger += 1
                     continue
                 if trigger == 2 and 'ip default-gateway' in line:
-                    self.gateway = ({'gateway': line.strip().split(' ')[-1]})
+                    self.gateway = line.strip().split(' ')[-1]
 
             return (self.ip, self.netmask, self.gateway)
 
